"""
@File       console_colors.py
@Brief      Colors
@Author     cavacagu
@Date       13-05-2019
@copyright  Microsoft Corporation. All rights reserved.
"""

#pylint: disable = too-few-public-methods
class ConsoleColors:
    """Console colors associated with various logging levels"""
    OK = '\033[92m'
    VERBOSE = '\033[36m'
    INFO = '\033[94m'
    ERROR = '\033[91m'
    WARNING = '\033[93m'
    END = '\033[0m'
#pylint: enable = too-few-public-methods
